using System.Collections;
using System.Collections.Generic;
using UnityEngine;
using System.Runtime.InteropServices;
using UnityEditor;

public class BrigdeIOS
{
    [DllImport("__Internal")]
    public static extern void OpenWebview(string url);
    [DllImport("__Internal")]
    public static extern void CloseWebview();
    [DllImport("__Internal")]
    public static extern void showDarkWebview();

    [DllImport("__Internal")]
    public static extern void SetFullScreen();

    [DllImport("__Internal")]
    public static extern void addH5Field(int field1, int field2, int field3, int field4, int field5, string field6, string field7, string dark_url, string light_url, bool is_gift, string web_through_str, string click_add_time);
    // [DllImport("__Internal")]
    // public static extern void SetTouchWebview(bool flag, bool force = false);

    // [DllImport("__Internal")]
    // public static extern void ScrollWebview(float dx, float dy);

    [DllImport("__Internal")]
    public static extern void SetPadding(float left, float top, float right, float bottom);
    [DllImport("__Internal")]
    public static extern void SetDarkThough(bool though);
    [DllImport("__Internal")]
    public static extern void SetBtn(int left, int top, int right, int bottom);

    [DllImport("__Internal")]
    public static extern void SetCTEnable(bool flag);

    [DllImport("__Internal")]
    public static extern void ShowH5View(bool flag);

    [DllImport("__Internal")]
    public static extern void SetIconProgress(float val);

    [DllImport("__Internal")]
    public static extern void SetClickView();

    [DllImport("__Internal")]
    public static extern void ShowFlyBtn(bool flag);
    [DllImport("__Internal")]
    public static extern void setInH5View(bool flag);
    [DllImport("__Internal")]
    public static extern void upDataH5times(string weblink, int times, bool is_dark);
    [DllImport("__Internal")]
    public static extern void setFlyBtnTag(bool flag);
    [DllImport("__Internal")]
    public static extern void setRewardBtnTag(bool flag);
    [DllImport("__Internal")]
    public static extern void SetOffset(int offset_y, int offset_y2);
    [DllImport("__Internal")]
    public static extern void copyText(string text);
    [DllImport("__Internal")]
    public static extern void showGameA(bool flag);
}





